// LS-30 handle mod for Happ Mechanical Rotary Joystick
// -- Handle

// See forums.arcadecontrols.com for full details

// Additional 3D prints:
// - Test print (check hardware fit before printing handle)
// - Shaft cover
// - Set screw cover
// - Dust washer (optional)

// Required hardware:
// - Happ Mechanical Rotary Joystick
// - 10mm shaft
// - 20x10x10mm shaft collar
// - M5x10mm setscrew

// Logo exported from Inkscape to .dxf file using https://github.com/brad/Inkscape-OpenSCAD-DXF-Export

// The following diagram labels all of the variables:
// (link to diagram)


/////////////////////////////
//  Adjustable variables
/////////////////////////////

// Logo
    LogoDepth = 1.0; // Default = 1.0
    // Logo height above the main body

// Dome
    DomeHeight = 0.8; // Default = 0.8
    // Dome height above the main body

    DomeDiameter = 22; // Default = 22
    // This variable is not used to generate the part, but is used to calculate DomeSphereRadius.

    DomeSphereRadius = 76.02; // Default = 76.02
    // Sphere radius that will generate the desired dome.
    // Enter the "Width of Arc" (DomeDiameter) and "Height of Arc" (DomeHeight) into the calculator at http://handymath.com/cgi-bin/arc18mm2.cgi?submit=Entry The resulting "Radius of Arc" = DomeSphereRadius.

// Body
    BodyHeight = 35.6; // Default = 35.6
    // Height of the body, not including the dome

// Sides
    SideRoundSphere = 0.7; // Default = 0.7
    // Radius of the side roundover sphere

    LowerBodyDiameter = 31.51; // Default = 31.51
    // Farthest distance from lower point-to-point edge

    UpperBodyDiameter = 29.41; // Default = 29.41
    // Farthest distance from upper point-to-point edge

// Bottom octagon
    LowerRoundSphere = 1.59; // Default = 1.59
    // Radius of the lower roundover sphere

// Top octagon
    UpperRoundSphere = 3.18; // Default = 3.18
    // Radius of the upper roundover sphere

// Spaces to remove from body
    ShaftHeight = 30; // Default = 30
    // Height of the shaft cavity

    ShaftDiameter = 10.35; // Default = 10.35
    // Diameter of the joystick shaft cavity

    ShaftCollarHeight = 9; // Default = 9
    // Height of the Shaft Collar cavity

    ShaftCollarOuterDiameter = 20.35; // Default = 20.35
    // Outer diameter of the Shaft Collar cavity

    SetScrewDiameter = 5.091; // Default = 5.091
    // Diameter of the Set Screw cavity

    SetScrewAngle = 0; // Default = 0
    // Angle of the set screw cavity -- 0° = hole on flat side of octagon, 22.5° = hole on point of octagon

// Number of fragments (polygon sides) used to render a full circle.
    $fn = 180; // Default = 180  Typical range = 6 - 360
    // 6 will render a circular hole as a hexagon, 8 will render a circular hole as an octagon.
    // Lower the number for faster rendering, raise the number for smoother rendering.


/////////////////////////////
//  Non-adjustable variables
/////////////////////////////

// Bottom octagon
    LowerSmallArccosine = SideRoundSphere * 1.0823922002923939687994464107328;
    // Calculates distance from center of lower small sphere to point of lower octagon [radius*acos(22.5)]

    LowerLargeArccosine = LowerRoundSphere * 1.0823922002923939687994464107328;
    // Calculates distance from point of lower octagon to center of lower large sphere [radius*acos(22.5)]

    LowerLargeSphereCenter = LowerBodyDiameter/2 - SideRoundSphere + LowerSmallArccosine - LowerLargeArccosine;
    // Rounded octagon point - side (small) sphere radius + distance from center of small sphere to point of octagon - distance from point of octagon to center of large sphere

// Top octagon
    UpperSmallArccosine = SideRoundSphere * 1.0823922002923939687994464107328;
    // Calculates distance from center of upper small sphere to point of upper octagon [radius*acos(22.5)]

    UpperLargeArccosine = UpperRoundSphere * 1.0823922002923939687994464107328;
    // Calculates distance from point of upper octagon to center of upper large sphere [radius*acos(22.5)]

    UpperLargeSphereCenter = UpperBodyDiameter/2 - SideRoundSphere + UpperSmallArccosine - UpperLargeArccosine;
    // Rounded octagon point - side (small) sphere radius + distance from center of small sphere to point of octagon - distance from point of octagon to center of large sphere

// Spaces to remove from body
    SetScrewLength = LowerBodyDiameter/2;
    // Set Screw Length


/////////////////////////////
//  Make the part
/////////////////////////////

// Make the SNK Logo (Optional)
// Comment out the next three lines to skip the logo
translate([-6, -3, BodyHeight])
linear_extrude(height = LogoDepth, convexity = 10)
import(file = "SNK_Logo.dxf", layer="Logo");
// The "SNK_Logo.dxf" file needs to be in the same directory as this SCAD file.
//

// Make the dome
difference(){ // Sphere minus cube
    translate([0,0,BodyHeight+DomeHeight-DomeSphereRadius]) sphere(r=DomeSphereRadius, center=true); // Sphere
    translate([0,0,BodyHeight-DomeSphereRadius]) cube([DomeSphereRadius*2,DomeSphereRadius*2,DomeSphereRadius*2], center=true);
    // Cube to cut off bottom of sphere
}
//

// Make the main body
difference(){ // Main body minus holes
    hull() {  // Main body hull
    // Lower roundover large spheres
    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 22.5]) translate ([LowerLargeSphereCenter, 0, LowerRoundSphere/2]) sphere (r = LowerRoundSphere);

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 67.5]) translate ([LowerLargeSphereCenter, 0, LowerRoundSphere/2]) sphere (r = LowerRoundSphere);

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 112.5]) translate ([LowerLargeSphereCenter, 0, LowerRoundSphere/2]) sphere (r = LowerRoundSphere);

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 157.5]) translate ([LowerLargeSphereCenter, 0, LowerRoundSphere/2]) sphere (r = LowerRoundSphere);     

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 202.5]) translate ([LowerLargeSphereCenter, 0, LowerRoundSphere/2]) sphere (r = LowerRoundSphere);     

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 247.5]) translate ([LowerLargeSphereCenter, 0, LowerRoundSphere/2]) sphere (r = LowerRoundSphere);     

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 292.5]) translate ([LowerLargeSphereCenter, 0, LowerRoundSphere/2]) sphere (r = LowerRoundSphere);     

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 337.5]) translate ([LowerLargeSphereCenter, 0, LowerRoundSphere/2]) sphere (r = LowerRoundSphere);     

    // Lower side small spheres
    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 22.5]) translate ([-SideRoundSphere + LowerBodyDiameter/2, 0, LowerRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 67.5]) translate ([-SideRoundSphere + LowerBodyDiameter/2, 0, LowerRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 112.5]) translate ([-SideRoundSphere + LowerBodyDiameter/2, 0, LowerRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 157.5]) translate ([-SideRoundSphere + LowerBodyDiameter/2, 0, LowerRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 202.5]) translate ([-SideRoundSphere + LowerBodyDiameter/2, 0, LowerRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 247.5]) translate ([-SideRoundSphere + LowerBodyDiameter/2, 0, LowerRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 292.5]) translate ([-SideRoundSphere + LowerBodyDiameter/2, 0, LowerRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, LowerRoundSphere/2])
    rotate ([0, 0, 337.5]) translate ([-SideRoundSphere + LowerBodyDiameter/2, 0, LowerRoundSphere/2]) sphere (r = SideRoundSphere);

    // Upper side small spheres
    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 22.5]) translate ([-SideRoundSphere + UpperBodyDiameter/2, 0, - UpperRoundSphere/2]) sphere (r = SideRoundSphere, center = true);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 67.5]) translate ([-SideRoundSphere + UpperBodyDiameter/2, 0, - UpperRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 112.5]) translate ([-SideRoundSphere + UpperBodyDiameter/2, 0, - UpperRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 157.5]) translate ([-SideRoundSphere + UpperBodyDiameter/2, 0, - UpperRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 202.5]) translate ([-SideRoundSphere + UpperBodyDiameter/2, 0, - UpperRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 247.5]) translate ([-SideRoundSphere + UpperBodyDiameter/2, 0, - UpperRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 292.5]) translate ([-SideRoundSphere + UpperBodyDiameter/2, 0, - UpperRoundSphere/2]) sphere (r = SideRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 337.5]) translate ([-SideRoundSphere + UpperBodyDiameter/2, 0, - UpperRoundSphere/2]) sphere (r = SideRoundSphere);

    // Upper roundover large spheres
    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 22.5]) translate ([UpperLargeSphereCenter, 0, - UpperRoundSphere/2]) sphere (r = UpperRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 67.5]) translate ([UpperLargeSphereCenter, 0, - UpperRoundSphere/2]) sphere (r = UpperRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 112.5]) translate ([UpperLargeSphereCenter, 0, - UpperRoundSphere/2]) sphere (r = UpperRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 157.5]) translate ([UpperLargeSphereCenter, 0, - UpperRoundSphere/2]) sphere (r = UpperRoundSphere);     

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 202.5]) translate ([UpperLargeSphereCenter, 0, - UpperRoundSphere/2]) sphere (r = UpperRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 247.5]) translate ([UpperLargeSphereCenter, 0, - UpperRoundSphere/2]) sphere (r = UpperRoundSphere);
    
    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 292.5]) translate ([UpperLargeSphereCenter, 0, - UpperRoundSphere/2]) sphere (r = UpperRoundSphere);

    translate ([0, 0, BodyHeight - UpperRoundSphere/2])
    rotate ([0, 0, 337.5]) translate ([UpperLargeSphereCenter, 0, - UpperRoundSphere/2]) sphere (r = UpperRoundSphere);
    } // End main body hull

// Holes
translate ([0, 0, ShaftHeight/2]) rotate ([0, 0, 0]) cylinder (ShaftHeight+2, d = ShaftDiameter, center=true); // Make hole for Shaft

translate ([0, 0, ShaftCollarHeight/2]) cylinder (2 + ShaftCollarHeight, d = ShaftCollarOuterDiameter, center=true); // Make hole for Shaft Collar

translate ([0, 0, ShaftCollarHeight/2]) // Set vertical position for Set Screw hole
    rotate ([90, 0, SetScrewAngle]) translate ([0, 0, ShaftCollarHeight/2]) cylinder (SetScrewLength+ShaftDiameter, d = SetScrewDiameter, center=true);
    // Rotate X-axis to turn cylinder horizontal, rotate Z-axis to point cylinder at either 0° (flat of octagon) or 22.5° (point of octagon), translate to move cylinder away from center, make hole for Set Screw
} //End difference main body hull minus holes
//